<?php

namespace App;

use Illuminate\Notifications\Notifiable;
use Illuminate\Contracts\Auth\MustVerifyEmail;
use Illuminate\Foundation\Auth\User as Authenticatable;

class User extends Authenticatable
{
    use Notifiable;

    /**
     * The attributes that are mass assignable.
     *
     * @var array
     */
    protected $fillable = [
        'name', 'email', 'password', 'google_id', 'added_by',
    ];

    /**
     * The attributes that should be hidden for arrays.
     *
     * @var array
     */
    protected $hidden = [
        'password', 'remember_token', 'google_id',
    ];

    /**
     * The attributes that should be cast to native types.
     *
     * @var array
     */
    protected $casts = [
        'email_verified_at' => 'datetime',
    ];

    public function permissions() {
        return $this->hasMany(Permission::class);
    }

    public function departments() {
        return $this->belongsToMany(Department::class, 'permissions', 'user_id', 'division_id')->wherePivot('level', '=', 1);
    }

    public function faculties() {
        return $this->belongsToMany(Faculty::class, 'permissions', 'user_id', 'division_id')->wherePivot('level', '=', 2);
    }

    public function getIsAdminAttribute() {
        return $this->permissions->where('level', '=', 3)->isNotEmpty();
    }
}
